@@ -41,7 +41,7 @@ class Client(object):
     _MPUT = 'PUT'
     _MPOST = 'POST'
     _MDELETE = 'DELETE'
-    _comparison_conditions = set(('prevValue', 'prevIndex', 'prevExist'))
+    _comparison_conditions = set(('prevValue', 'prevIndex', 'prevExist', 'refresh'))
     _read_options = set(('recursive', 'wait', 'waitIndex', 'sorted', 'quorum'))
     _del_conditions = set(('prevValue', 'prevIndex'))
 
@@ -63,7 +63,8 @@ class Client(object):
             allow_reconnect=False,
             use_proxies=False,
             expected_cluster_id=None,
-            per_host_pool_size=10
+            per_host_pool_size=10,
+            lock_prefix="/_locks"
     ):
         """
         Initialize the client.
@@ -111,6 +112,8 @@ class Client(object):
             per_host_pool_size (int): specifies maximum number of connections to pool
                                       by host. By default this will use up to 10
                                       connections.
+            lock_prefix (str): Set the key prefix at etcd when client to lock object.
+                                      By default this will be use /_locks.
         """
 
         # If a DNS record is provided, use it to get the hosts list
@@ -143,6 +146,7 @@ class Client(object):
         self._allow_redirect = allow_redirect
         self._use_proxies = use_proxies
         self._allow_reconnect = allow_reconnect
+        self._lock_prefix = lock_prefix
 
         # SSL Client certificate support
 
@@ -153,12 +157,6 @@ class Client(object):
         if self._read_timeout > 0:
             kw['timeout'] = self._read_timeout
 
-        if protocol == 'https':
-            # If we don't allow TLSv1, clients using older version of OpenSSL
-            # (<1.0) won't be able to connect.
-            _log.debug("HTTPS enabled.")
-            kw['ssl_version'] = ssl.PROTOCOL_TLSv1
-
         if cert:
             if isinstance(cert, tuple):
                 # Key and cert are separate
@@ -258,6 +256,11 @@ class Client(object):
         """Allow the client to connect to other nodes."""
         return self._allow_redirect
 
+    @property
+    def lock_prefix(self):
+        """Get the key prefix at etcd when client to lock object."""
+        return self._lock_prefix
+
     @property
     def machines(self):
         """
@@ -397,10 +400,9 @@ class Client(object):
             key = "/{}".format(key)
         return key
 
-
     def write(self, key, value, ttl=None, dir=False, append=False, **kwdargs):
         """
-        Writes the value for a key, possibly doing atomit Compare-and-Swap
+        Writes the value for a key, possibly doing atomic Compare-and-Swap
 
         Args:
             key (str):  Key.
@@ -422,6 +424,8 @@ class Client(object):
 
             prevExist (bool): If false, only create key; if true, only update key.
 
+            refresh (bool): since 2.3.0, If true, only update the ttl, prev key must existed(prevExist=True).
+
         Returns:
             client.EtcdResult
 
@@ -430,7 +434,7 @@ class Client(object):
 
         """
         _log.debug("Writing %s to key %s ttl=%s dir=%s append=%s",
-                  value, key, ttl, dir, append)
+                   value, key, ttl, dir, append)
         key = self._sanitize_key(key)
         params = {}
         if value is not None:
@@ -461,6 +465,28 @@ class Client(object):
         response = self.api_execute(path, method, params=params)
         return self._result_from_response(response)
 
+    def refresh(self, key, ttl, **kwdargs):
+        """
+        (Since 2.3.0) Refresh the ttl of a key without notifying watchers.
+
+        Keys in etcd can be refreshed without notifying watchers,
+        this can be achieved by setting the refresh to true when updating a TTL
+
+        You cannot update the value of a key when refreshing it
+
+        @see: https://github.com/coreos/etcd/blob/release-2.3/Documentation/api.md#refreshing-key-ttl
+
+        Args:
+            key (str):  Key.
+
+            ttl (int):  Time in seconds of expiration (optional).
+
+            Other parameters modifying the write method are accepted as `EtcdClient.write`.
+        """
+        # overwrite kwdargs' prevExist
+        kwdargs['prevExist'] = True
+        return self.write(key=key, value=None, ttl=ttl, refresh=True, **kwdargs)
+
     def update(self, obj):
         """
         Updates the value for a key atomically. Typical usage would be:
